package com.ericfeminella.examples.business
{
	import com.ericfeminella.examples.model.domain.IContact;
	import com.ericfeminella.sql.dao.AbstractSynchronizedSQLDAO;
	import com.ericfeminella.sql.utils.SQLConnectionHelper;
	import flash.data.SQLConnection;
	import flash.data.SQLResult;
	import flash.filesystem.File;
	import mx.collections.ArrayCollection;

	/**
	 * 
	 * Concrete <code>IContactDAO</code> implementation for accessing a local
	 * SQL database.
	 * 
	 */
	public class SQLContactDAO extends AbstractSynchronizedSQLDAO implements IContactDAO
	{
		protected var statements:ContactsSQLStatements;
		
		public function SQLContactDAO()
		{
			var databasePath:String = File.desktopDirectory.nativePath + File.separator + "contacts.db"
			var databaseFile:File = new File( databasePath );
			var connection:SQLConnection = SQLConnectionHelper.getConnection( databasePath );
			
			super( connection, databaseFile );
			
			this.statements = new ContactsSQLStatements( connection );
            this.executeStatement( statements.createContactsTableStatement );	
		}

		public function getContacts() : ArrayCollection
		{
            var result:SQLResult = executeStatement( statements.selectedContactsStatement );
			return new ArrayCollection( result.data as Array );
		}
		
		public function createContact(contact:IContact) : void
		{
             var result:SQLResult = executeStatement( statements.insertContactStatement, 
                                                      contact.firstName, 
                                                      contact.lastName,
                                                      contact.emailAddress );
             contact.contactId = result.lastInsertRowID;
		}
		
		public function getContact(contact:IContact) : IContact
		{
            var result:SQLResult = executeStatement( statements.updateContactStatement, contact.contactId )
            var contact:IContact = result.data as IContact;
            
            return contact;
		}
		
		public function updateContact(contact:IContact) : void
		{
            executeStatement( statements.updateContactStatement, contact.firstName,
                                                 contact.firstName,
                                                 contact.emailAddress,
                                                 contact.contactId );
		}
		
		public function deleteContact(contact:IContact) : void
		{
            executeStatement( statements.deleteContactStatement, contact.contactId );	
		}
	}
}
